/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.ratings.internal.change.tracking.spi.reference;

import com.liferay.change.tracking.spi.reference.TableReferenceDefinition;
import com.liferay.change.tracking.spi.reference.builder.ChildTableReferenceInfoBuilder;
import com.liferay.change.tracking.spi.reference.builder.ParentTableReferenceInfoBuilder;
import com.liferay.portal.kernel.model.CompanyTable;
import com.liferay.portal.kernel.service.persistence.BasePersistence;
import com.liferay.ratings.kernel.model.RatingsEntryTable;
import com.liferay.ratings.kernel.model.RatingsStatsTable;
import com.liferay.ratings.kernel.service.persistence.RatingsStatsPersistence;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Preston Crary
 */
@Component(service = TableReferenceDefinition.class)
public class RatingsStatsTableReferenceDefinition
	implements TableReferenceDefinition<RatingsStatsTable> {

	@Override
	public void defineChildTableReferences(
		ChildTableReferenceInfoBuilder<RatingsStatsTable>
			childTableReferenceInfoBuilder) {

		childTableReferenceInfoBuilder.referenceInnerJoin(
			fromStep -> fromStep.from(
				RatingsEntryTable.INSTANCE
			).innerJoinON(
				RatingsStatsTable.INSTANCE,
				RatingsStatsTable.INSTANCE.classNameId.eq(
					RatingsEntryTable.INSTANCE.classNameId
				).and(
					RatingsStatsTable.INSTANCE.classPK.eq(
						RatingsEntryTable.INSTANCE.classPK)
				)
			));
	}

	@Override
	public void defineParentTableReferences(
		ParentTableReferenceInfoBuilder<RatingsStatsTable>
			parentTableReferenceInfoBuilder) {

		parentTableReferenceInfoBuilder.singleColumnReference(
			RatingsStatsTable.INSTANCE.companyId,
			CompanyTable.INSTANCE.companyId);
	}

	@Override
	public BasePersistence<?> getBasePersistence() {
		return _ratingsStatsPersistence;
	}

	@Override
	public RatingsStatsTable getTable() {
		return RatingsStatsTable.INSTANCE;
	}

	@Reference
	private RatingsStatsPersistence _ratingsStatsPersistence;

}